summaryrefslogtreecommitdiff
path: root/usr.bin/mandoc/out.h
diff options
context:
space:
mode:
Diffstat (limited to 'usr.bin/mandoc/out.h')
-rw-r--r--usr.bin/mandoc/out.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/usr.bin/mandoc/out.h b/usr.bin/mandoc/out.h
index 4856dfbd08a..7e93f1c0700 100644
--- a/usr.bin/mandoc/out.h
+++ b/usr.bin/mandoc/out.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: out.h,v 1.19 2017/06/08 12:54:40 schwarze Exp $ */
+/* $OpenBSD: out.h,v 1.20 2017/06/08 18:11:15 schwarze Exp $ */
/*
* Copyright (c) 2009, 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
* Copyright (c) 2014, 2017 Ingo Schwarze <schwarze@openbsd.org>
@@ -41,14 +41,16 @@ struct roffsu {
double scale;
};
+typedef size_t (*tbl_sulen)(const struct roffsu *, void *);
typedef size_t (*tbl_strlen)(const char *, void *);
typedef size_t (*tbl_len)(size_t, void *);
struct rofftbl {
+ tbl_sulen sulen; /* calculate scaling unit length */
tbl_strlen slen; /* calculate string length */
tbl_len len; /* produce width of empty space */
struct roffcol *cols; /* master column specifiers */
- void *arg; /* passed to slen and len */
+ void *arg; /* passed to sulen, slen, and len */
};
#define SCALE_VS_INIT(p, v) \